@@ -877,9 +877,9 @@ class Grid:
 
     def shift_node(self,
                    node,
-                   delta_x,
-                   delta_y,
-                   allow_shifting_node_outside_boundary=True):
+                   delta_x: float,
+                   delta_y: float,
+                   allow_shifting_node_outside_boundary: bool = True):
         """
         This method increment the 'pixel_x_axis' value by delta_x and the
         'pixel_y_axis' value by delta_y for the node given as parameter.
@@ -901,13 +901,17 @@ class Grid:
 
         # Detect if shifting the node would make it leave image boundary
         new_coord_within_boundary = (
-            self.get_nodes['pixel_x_axis'][node] +
+            self.get_nodes()['pixel_x_axis'][node] +
             delta_x <= self.get_image().shape[0]
-            and self.get_nodes['pixel_x_axis'][node] + delta_x >= 0
-            and self.get_nodes[
+            and self.get_nodes()['pixel_x_axis'][node] + delta_x >= 0
+            and self.get_nodes()[
                 'pixel_y_axis'][node] + delta_y <= self.get_image().shape[1]
-            and self.get_nodes[
+            and self.get_nodes()[
                 'pixel_y_axis'][node] + delta_y >= 0)
+        print(
+            f"self.__nodes.at[node, 'pixel_x_axis'] : {self.__nodes.at[node, 'pixel_x_axis']}\ndelta_x: {delta_x}")
+        print(
+            f"self.__nodes.at[node, 'pixel_y_axis'] : {self.__nodes.at[node, 'pixel_y_axis']}\ndelta_x: {delta_y}")
 
         if new_coord_within_boundary or allow_shifting_node_outside_boundary:
             # shift node
